@@ -1,25 +1,18 @@
 module Main.Prelude
-( 
-  module Exports,
-  LazyByteString,
-  ByteStringBuilder,
-  LazyText,
-  TextBuilder,
-)
+  ( module Exports,
+    LazyByteString,
+    ByteStringBuilder,
+    LazyText,
+    TextBuilder,
+  )
 where
 
-
--- rerebase
--------------------------
-import Prelude as Exports hiding (assert, Data, fail, check)
-
--- custom
--------------------------
-import qualified Data.ByteString.Lazy
 import qualified Data.ByteString.Builder
+import qualified Data.ByteString.Lazy
 import qualified Data.Text.Lazy
 import qualified Data.Text.Lazy.Builder
-
+import Test.QuickCheck.Instances ()
+import Prelude as Exports hiding (Data, assert, check, fail)
 
 type LazyByteString =
   Data.ByteString.Lazy.ByteString
@@ -32,4 +25,3 @@ type LazyText =
 
 type TextBuilder =
   Data.Text.Lazy.Builder.Builder
-
